DebugResponseConverter class
Methods
-
convertRequest(Request request)
→ FutureOr<Request>
-
Converts the received
Request to a Request which has a body with the
HTTP representation of the original body.
-
convertResponse<BodyType, InnerType>(Response response)
→ FutureOr<Response<BodyType>>
-
Converts the received
Response to a Response which has a body of the
type BodyType.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited