DebugResponseError class

Implemented types

Constructors

DebugResponseError({required Object error, required String endpoint, required bool showNotice, String? maintainerLogline, Object? maintainerLoglineError, String? diagnosticLogline})
const

Properties

diagnosticLogline String?
final
endpoint String
final
error Object
final
hashCode int
The hash code for this object.
no setterinherited
isSpecValidationError bool
no setter
maintainerLogline String?
final
maintainerLoglineError Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNotice bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited