toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final parts = <String>[];
  if (showNotice) {
    parts.add(debugResponseNotice);
    parts.add("\n");
  }
  if (maintainerLogline != null) {
    parts.add(
      " Debug response logline for maintainers (endpoint \"$endpoint\"): ",
    );
    parts.add(maintainerLogline!);
  }
  if (maintainerLoglineError != null) {
    parts.add("private debug logline build error: $maintainerLoglineError.");
  }
  if (diagnosticLogline != null) {
    if (maintainerLogline != null || maintainerLoglineError != null) {
      parts.add("\n");
    }
    parts.add(
      " Debug response logline for local debug (endpoint \"$endpoint\"): ",
    );
    parts.add(diagnosticLogline!);
  }

  final renderedDebugResponse = parts.join("");
  if (renderedDebugResponse.isEmpty) {
    return error.toString();
  }
  return "${error.toString()}\n$renderedDebugResponse";
}