DebugResponseLogline class
Constructors
Properties
- body → Uint8List
-
final
- client → String
-
final
- contentType → String
-
final
- endpoint → String
-
final
- error → Object
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkVersion → String
-
final
- specVersion → String
-
final
- statusCode → int
-
final
Methods
-
marshal(
{required bool includeBody}) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited