DebugResponseOptions class
Constructors
- DebugResponseOptions({bool showNotice = true, bool includeMaintainerLogline = true, bool includeDiagnosticLogline = false})
-
const
Properties
- enabled → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeDiagnosticLogline → bool
-
final
- includeMaintainerLogline → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showNotice → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaults → const DebugResponseOptions
- disabled → const DebugResponseOptions