DebugResponses class
Constructors
- DebugResponses({required String client, required String sdkVersion, required String specVersion, required DebugResponseOptions options})
Properties
- client → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → DebugResponseOptions
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkVersion → String
-
final
- specVersion → String
-
final
Methods
-
decorate(
{required Response response, required Object error}) → Future< Object> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited