CourseCategoryCover enum

Inheritance
Available extensions

Values

swaggerGeneratedUnknown → const CourseCategoryCover
const CourseCategoryCover(null)
sinewave → const CourseCategoryCover
const CourseCategoryCover('sineWave')
curvesgrid → const CourseCategoryCover
const CourseCategoryCover('curvesGrid')
ellipsesoverlap → const CourseCategoryCover
const CourseCategoryCover('ellipsesOverlap')
geometrictriangle → const CourseCategoryCover
const CourseCategoryCover('geometricTriangle')
verticallines → const CourseCategoryCover
const CourseCategoryCover('verticalLines')
gridplanes → const CourseCategoryCover
const CourseCategoryCover('gridPlanes')
spiralloops → const CourseCategoryCover
const CourseCategoryCover('spiralLoops')
symmetriccircles → const CourseCategoryCover
const CourseCategoryCover('symmetricCircles')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CourseCategoryCover>
A constant List of the values in this enum, in order of their declaration.