VideoPlatformState enum

Inheritance
Available extensions

Values

swaggerGeneratedUnknown → const VideoPlatformState
const VideoPlatformState(null)
unspecified → const VideoPlatformState
const VideoPlatformState('unspecified')
empty → const VideoPlatformState
const VideoPlatformState('empty')
uploaded → const VideoPlatformState
const VideoPlatformState('uploaded')
transcoding → const VideoPlatformState
const VideoPlatformState('transcoding')
viewable → const VideoPlatformState
const VideoPlatformState('viewable')
ready → const VideoPlatformState
const VideoPlatformState('ready')
partiallyready → const VideoPlatformState
const VideoPlatformState('partiallyReady')
error → const VideoPlatformState
const VideoPlatformState('error')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VideoPlatformState>
A constant List of the values in this enum, in order of their declaration.