BaseBadRequestError class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BaseBadRequestError({required String title, required int status, required Map<String, dynamic> errors})
const
BaseBadRequestError.fromJson(Map<String, dynamic> json)
factory

Properties

errors Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
final
title String
final

Methods

copyWith({String? title, int? status, Map<String, dynamic>? errors}) BaseBadRequestError

Available on BaseBadRequestError, provided by the $BaseBadRequestErrorExtension extension

copyWithWrapped({Wrapped<String>? title, Wrapped<int>? status, Wrapped<Map<String, dynamic>>? errors}) BaseBadRequestError

Available on BaseBadRequestError, provided by the $BaseBadRequestErrorExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const BaseBadRequestError Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BaseBadRequestError instance)