BaseForbiddenError class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BaseForbiddenError({String? type, required String title, required int status, String? detail, String? instance, required String traceId})
const
BaseForbiddenError.fromJson(Map<String, dynamic> json)
factory

Properties

detail String?
final
hashCode int
The hash code for this object.
no setteroverride
instance String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
final
title String
final
traceId String
final
type String?
final

Methods

copyWith({String? type, String? title, int? status, String? detail, String? instance, String? traceId}) BaseForbiddenError

Available on BaseForbiddenError, provided by the $BaseForbiddenErrorExtension extension

copyWithWrapped({Wrapped<String?>? type, Wrapped<String>? title, Wrapped<int>? status, Wrapped<String?>? detail, Wrapped<String?>? instance, Wrapped<String>? traceId}) BaseForbiddenError

Available on BaseForbiddenError, provided by the $BaseForbiddenErrorExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const BaseForbiddenError Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BaseForbiddenError instance)