BaseNotFoundError class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BaseNotFoundError({required String title, required int status, String? detail, String? instance, int? entityId, required String traceId})
const
BaseNotFoundError.fromJson(Map<String, dynamic> json)
factory

Properties

detail String?
final
entityId int?
final
hashCode int
The hash code for this object.
no setteroverride
instance String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
final
title String
final
traceId String
final

Methods

copyWith({String? title, int? status, String? detail, String? instance, int? entityId, String? traceId}) BaseNotFoundError

Available on BaseNotFoundError, provided by the $BaseNotFoundErrorExtension extension

copyWithWrapped({Wrapped<String>? title, Wrapped<int>? status, Wrapped<String?>? detail, Wrapped<String?>? instance, Wrapped<int?>? entityId, Wrapped<String>? traceId}) BaseNotFoundError

Available on BaseNotFoundError, provided by the $BaseNotFoundErrorExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const BaseNotFoundError Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BaseNotFoundError instance)