BaseProblemError class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

BaseProblemError({String? type, required String title, required int status, String? traceId})
const
BaseProblemError.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
final
title String
final
traceId String?
final
type String?
final

Methods

copyWith({String? type, String? title, int? status, String? traceId}) BaseProblemError

Available on BaseProblemError, provided by the $BaseProblemErrorExtension extension

copyWithWrapped({Wrapped<String?>? type, Wrapped<String>? title, Wrapped<int>? status, Wrapped<String?>? traceId}) BaseProblemError

Available on BaseProblemError, provided by the $BaseProblemErrorExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const BaseProblemError Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(BaseProblemError instance)