CourseOverviewByIdResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CourseOverviewByIdResponse({required int id, required String name, required bool isArchived, required PublicationState state, required String? publishDate, required String? publishedAt, required CourseSettings settings, required List<CourseThemeItem> themes})
const
CourseOverviewByIdResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
final
isArchived bool
final
name String
final
publishDate String?
final
publishedAt String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings CourseSettings
final
state PublicationState
final
themes List<CourseThemeItem>
final

Methods

copyWith({int? id, String? name, bool? isArchived, PublicationState? state, String? publishDate, String? publishedAt, CourseSettings? settings, List<CourseThemeItem>? themes}) CourseOverviewByIdResponse

Available on CourseOverviewByIdResponse, provided by the $CourseOverviewByIdResponseExtension extension

copyWithWrapped({Wrapped<int>? id, Wrapped<String>? name, Wrapped<bool>? isArchived, Wrapped<PublicationState>? state, Wrapped<String?>? publishDate, Wrapped<String?>? publishedAt, Wrapped<CourseSettings>? settings, Wrapped<List<CourseThemeItem>>? themes}) CourseOverviewByIdResponse

Available on CourseOverviewByIdResponse, provided by the $CourseOverviewByIdResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const CourseOverviewByIdResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(CourseOverviewByIdResponse instance)