CourseSettings class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CourseSettings({required CourseSkillLevel skillLevel, required bool isSkillLevelEnabled, required String? syllabusUrl, required String? timeChannelUrl})
const
CourseSettings.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
isSkillLevelEnabled bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillLevel CourseSkillLevel
final
syllabusUrl String?
final
timeChannelUrl String?
final

Methods

copyWith({CourseSkillLevel? skillLevel, bool? isSkillLevelEnabled, String? syllabusUrl, String? timeChannelUrl}) CourseSettings

Available on CourseSettings, provided by the $CourseSettingsExtension extension

copyWithWrapped({Wrapped<CourseSkillLevel>? skillLevel, Wrapped<bool>? isSkillLevelEnabled, Wrapped<String?>? syllabusUrl, Wrapped<String?>? timeChannelUrl}) CourseSettings

Available on CourseSettings, provided by the $CourseSettingsExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const CourseSettings Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(CourseSettings instance)