CourseSummaryItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CourseSummaryItem({required int id, required String name, required PublicationState state, required String? publishDate, required String? publishedAt, required CourseSettings settings, required int? subjectId, required bool isArchived, required CourseCategory category, required CourseCategoryCover categoryCover})
const
CourseSummaryItem.fromJson(Map<String, dynamic> json)
factory

Properties

category CourseCategory
final
categoryCover CourseCategoryCover
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
isArchived bool
final
name String
final
publishDate String?
final
publishedAt String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings CourseSettings
final
state PublicationState
final
subjectId int?
final

Methods

copyWith({int? id, String? name, PublicationState? state, String? publishDate, String? publishedAt, CourseSettings? settings, int? subjectId, bool? isArchived, CourseCategory? category, CourseCategoryCover? categoryCover}) CourseSummaryItem

Available on CourseSummaryItem, provided by the $CourseSummaryItemExtension extension

copyWithWrapped({Wrapped<int>? id, Wrapped<String>? name, Wrapped<PublicationState>? state, Wrapped<String?>? publishDate, Wrapped<String?>? publishedAt, Wrapped<CourseSettings>? settings, Wrapped<int?>? subjectId, Wrapped<bool>? isArchived, Wrapped<CourseCategory>? category, Wrapped<CourseCategoryCover>? categoryCover}) CourseSummaryItem

Available on CourseSummaryItem, provided by the $CourseSummaryItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const CourseSummaryItem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(CourseSummaryItem instance)