CourseThemeItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
CourseThemeItem({required int id, required String name, required int order, required PublicationState state, required String? publishDate, required String? publishedAt, required List<
LongreadItem> longreads}) -
const
-
CourseThemeItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
-
longreads
→ List<
LongreadItem> -
final
- name → String
-
final
- order → int
-
final
- publishDate → String?
-
final
- publishedAt → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → PublicationState
-
final
Methods
-
copyWith(
{int? id, String? name, int? order, PublicationState? state, String? publishDate, String? publishedAt, List< LongreadItem> ? longreads}) → CourseThemeItem -
Available on CourseThemeItem, provided by the $CourseThemeItemExtension extension
-
copyWithWrapped(
{Wrapped< int> ? id, Wrapped<String> ? name, Wrapped<int> ? order, Wrapped<PublicationState> ? state, Wrapped<String?> ? publishDate, Wrapped<String?> ? publishedAt, Wrapped<List< ? longreads}) → CourseThemeItemLongreadItem> > -
Available on CourseThemeItem, provided by the $CourseThemeItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const CourseThemeItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(CourseThemeItem instance)