CourseThemeSummaryByIdResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

CourseThemeSummaryByIdResponse({required int id, required String name, required PublicationState state, required String? publishDate, required String? publishedAt, required int order, required CourseCategory category, required int categoryCover})
const
CourseThemeSummaryByIdResponse.fromJson(Map<String, dynamic> json)
factory

Properties

category CourseCategory
final
categoryCover int
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
name String
final
order int
final
publishDate String?
final
publishedAt String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state PublicationState
final

Methods

copyWith({int? id, String? name, PublicationState? state, String? publishDate, String? publishedAt, int? order, CourseCategory? category, int? categoryCover}) CourseThemeSummaryByIdResponse

Available on CourseThemeSummaryByIdResponse, provided by the $CourseThemeSummaryByIdResponseExtension extension

copyWithWrapped({Wrapped<int>? id, Wrapped<String>? name, Wrapped<PublicationState>? state, Wrapped<String?>? publishDate, Wrapped<String?>? publishedAt, Wrapped<int>? order, Wrapped<CourseCategory>? category, Wrapped<int>? categoryCover}) CourseThemeSummaryByIdResponse

Available on CourseThemeSummaryByIdResponse, provided by the $CourseThemeSummaryByIdResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const CourseThemeSummaryByIdResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(CourseThemeSummaryByIdResponse instance)