ExerciseItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ExerciseItem({required int id, required String name, required num maxScore, required ActivityDefinition activity, required String deadline})
const
ExerciseItem.fromJson(Map<String, dynamic> json)
factory

Properties

activity ActivityDefinition
final
deadline String
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
maxScore num
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? name, num? maxScore, ActivityDefinition? activity, String? deadline}) ExerciseItem

Available on ExerciseItem, provided by the $ExerciseItemExtension extension

copyWithWrapped({Wrapped<int>? id, Wrapped<String>? name, Wrapped<num>? maxScore, Wrapped<ActivityDefinition>? activity, Wrapped<String>? deadline}) ExerciseItem

Available on ExerciseItem, provided by the $ExerciseItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ExerciseItem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ExerciseItem instance)