GenerateContentDownloadLinkResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GenerateContentDownloadLinkResponse({required String url})
const
GenerateContentDownloadLinkResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

copyWith({String? url}) GenerateContentDownloadLinkResponse

Available on GenerateContentDownloadLinkResponse, provided by the $GenerateContentDownloadLinkResponseExtension extension

copyWithWrapped({Wrapped<String>? url}) GenerateContentDownloadLinkResponse

Available on GenerateContentDownloadLinkResponse, provided by the $GenerateContentDownloadLinkResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const GenerateContentDownloadLinkResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(GenerateContentDownloadLinkResponse instance)