ListStudentCoursesResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

ListStudentCoursesResponse({required List<CourseSummaryItem> items, required Paging paging})
const
ListStudentCoursesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
items List<CourseSummaryItem>
final
paging Paging
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<CourseSummaryItem>? items, Paging? paging}) ListStudentCoursesResponse

Available on ListStudentCoursesResponse, provided by the $ListStudentCoursesResponseExtension extension

copyWithWrapped({Wrapped<List<CourseSummaryItem>>? items, Wrapped<Paging>? paging}) ListStudentCoursesResponse

Available on ListStudentCoursesResponse, provided by the $ListStudentCoursesResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const ListStudentCoursesResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(ListStudentCoursesResponse instance)