LongreadExerciseSingleChoiceQuestionitem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LongreadExerciseSingleChoiceQuestionitem({required LongreadExerciseSingleChoiceQuestionitemType type, required int id, required int order, required String content, required num score, required List<LongreadMaterialAttachmentItem> attachments, required List<QuestionItemOption> options, required bool areOptionsShuffled, required LongreadExerciseSingleChoiceQuestionitem$SingleChoice singleChoice})
const
LongreadExerciseSingleChoiceQuestionitem.fromJson(Map<String, dynamic> json)
factory

Properties

areOptionsShuffled bool
final
attachments List<LongreadMaterialAttachmentItem>
final
content String
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
options List<QuestionItemOption>
final
order int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score num
final
singleChoice LongreadExerciseSingleChoiceQuestionitem$SingleChoice
final
type LongreadExerciseSingleChoiceQuestionitemType
final

Methods

copyWith({LongreadExerciseSingleChoiceQuestionitemType? type, int? id, int? order, String? content, num? score, List<LongreadMaterialAttachmentItem>? attachments, List<QuestionItemOption>? options, bool? areOptionsShuffled, LongreadExerciseSingleChoiceQuestionitem$SingleChoice? singleChoice}) LongreadExerciseSingleChoiceQuestionitem

Available on LongreadExerciseSingleChoiceQuestionitem, provided by the $LongreadExerciseSingleChoiceQuestionitemExtension extension

copyWithWrapped({Wrapped<LongreadExerciseSingleChoiceQuestionitemType>? type, Wrapped<int>? id, Wrapped<int>? order, Wrapped<String>? content, Wrapped<num>? score, Wrapped<List<LongreadMaterialAttachmentItem>>? attachments, Wrapped<List<QuestionItemOption>>? options, Wrapped<bool>? areOptionsShuffled, Wrapped<LongreadExerciseSingleChoiceQuestionitem$SingleChoice>? singleChoice}) LongreadExerciseSingleChoiceQuestionitem

Available on LongreadExerciseSingleChoiceQuestionitem, provided by the $LongreadExerciseSingleChoiceQuestionitemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LongreadExerciseSingleChoiceQuestionitem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LongreadExerciseSingleChoiceQuestionitem instance)