LongreadItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LongreadItem({required int id, required LongreadType type, required String name, required PublicationState state, required String? publishDate, required String? publishedAt, required List<ExerciseItem> exercises})
const
LongreadItem.fromJson(Map<String, dynamic> json)
factory

Properties

exercises List<ExerciseItem>
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
name String
final
publishDate String?
final
publishedAt String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state PublicationState
final
type LongreadType
final

Methods

copyWith({int? id, LongreadType? type, String? name, PublicationState? state, String? publishDate, String? publishedAt, List<ExerciseItem>? exercises}) LongreadItem

Available on LongreadItem, provided by the $LongreadItemExtension extension

copyWithWrapped({Wrapped<int>? id, Wrapped<LongreadType>? type, Wrapped<String>? name, Wrapped<PublicationState>? state, Wrapped<String?>? publishDate, Wrapped<String?>? publishedAt, Wrapped<List<ExerciseItem>>? exercises}) LongreadItem

Available on LongreadItem, provided by the $LongreadItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LongreadItem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LongreadItem instance)