LongreadMaterialAttachmentItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LongreadMaterialAttachmentItem({required String name, required String filename, required FileMediaType mediaType, required int length, required String? version})
const
LongreadMaterialAttachmentItem.fromJson(Map<String, dynamic> json)
factory

Properties

filename String
final
hashCode int
The hash code for this object.
no setteroverride
length int
final
mediaType FileMediaType
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
final

Methods

copyWith({String? name, String? filename, FileMediaType? mediaType, int? length, String? version}) LongreadMaterialAttachmentItem

Available on LongreadMaterialAttachmentItem, provided by the $LongreadMaterialAttachmentItemExtension extension

copyWithWrapped({Wrapped<String>? name, Wrapped<String>? filename, Wrapped<FileMediaType>? mediaType, Wrapped<int>? length, Wrapped<String?>? version}) LongreadMaterialAttachmentItem

Available on LongreadMaterialAttachmentItem, provided by the $LongreadMaterialAttachmentItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LongreadMaterialAttachmentItem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LongreadMaterialAttachmentItem instance)