LongreadMaterialContent class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LongreadMaterialContent({required String name, required String filename, required LongreadMaterialMediaTypeUpper mediaType, required String? version, required int length})
const
LongreadMaterialContent.fromJson(Map<String, dynamic> json)
factory

Properties

filename String
final
hashCode int
The hash code for this object.
no setteroverride
length int
final
mediaType LongreadMaterialMediaTypeUpper
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
final

Methods

copyWith({String? name, String? filename, LongreadMaterialMediaTypeUpper? mediaType, String? version, int? length}) LongreadMaterialContent

Available on LongreadMaterialContent, provided by the $LongreadMaterialContentExtension extension

copyWithWrapped({Wrapped<String>? name, Wrapped<String>? filename, Wrapped<LongreadMaterialMediaTypeUpper>? mediaType, Wrapped<String?>? version, Wrapped<int>? length}) LongreadMaterialContent

Available on LongreadMaterialContent, provided by the $LongreadMaterialContentExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LongreadMaterialContent Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LongreadMaterialContent instance)