LongreadMaterialEstimation class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LongreadMaterialEstimation({required String startDate, required String? timer, double? maxScore, DateTime? deadline, LongreadMaterialActivity? activity})
const
LongreadMaterialEstimation.fromJson(Map<String, dynamic> json)
factory

Properties

activity LongreadMaterialActivity?
final
deadline DateTime?
final
hashCode int
The hash code for this object.
no setteroverride
maxScore double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate String
final
timer String?
final

Methods

copyWith({String? startDate, String? timer, double? maxScore, DateTime? deadline, LongreadMaterialActivity? activity}) LongreadMaterialEstimation

Available on LongreadMaterialEstimation, provided by the $LongreadMaterialEstimationExtension extension

copyWithWrapped({Wrapped<String>? startDate, Wrapped<String?>? timer, Wrapped<double?>? maxScore, Wrapped<DateTime?>? deadline, Wrapped<LongreadMaterialActivity?>? activity}) LongreadMaterialEstimation

Available on LongreadMaterialEstimation, provided by the $LongreadMaterialEstimationExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LongreadMaterialEstimation Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LongreadMaterialEstimation instance)