LongreadMaterialsByIdResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LongreadMaterialsByIdResponse({required List<LongreadMaterialItem> items, required Paging paging})
const
LongreadMaterialsByIdResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
items List<LongreadMaterialItem>
final
paging Paging
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<LongreadMaterialItem>? items, Paging? paging}) LongreadMaterialsByIdResponse

Available on LongreadMaterialsByIdResponse, provided by the $LongreadMaterialsByIdResponseExtension extension

copyWithWrapped({Wrapped<List<LongreadMaterialItem>>? items, Wrapped<Paging>? paging}) LongreadMaterialsByIdResponse

Available on LongreadMaterialsByIdResponse, provided by the $LongreadMaterialsByIdResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LongreadMaterialsByIdResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LongreadMaterialsByIdResponse instance)