LongreadVideoMaterialItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LongreadVideoMaterialItem({required LongreadMaterialDiscriminator discriminator, required PublicationState state, required LongreadMaterialViewType viewType, required LongreadMaterialType type, required int id, required int order, required FileMediaType mediaType, required String filename, required String? version, required int length, required String? publishDate, required String? publishedAt, required LongreadMaterialContent content})
const
LongreadVideoMaterialItem.fromJson(Map<String, dynamic> json)
factory

Properties

content LongreadMaterialContent
final
discriminator LongreadMaterialDiscriminator
final
filename String
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
length int
final
mediaType FileMediaType
final
order int
final
publishDate String?
final
publishedAt String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state PublicationState
final
type LongreadMaterialType
final
version String?
final
viewType LongreadMaterialViewType
final

Methods

copyWith({LongreadMaterialDiscriminator? discriminator, PublicationState? state, LongreadMaterialViewType? viewType, LongreadMaterialType? type, int? id, int? order, FileMediaType? mediaType, String? filename, String? version, int? length, String? publishDate, String? publishedAt, LongreadMaterialContent? content}) LongreadVideoMaterialItem

Available on LongreadVideoMaterialItem, provided by the $LongreadVideoMaterialItemExtension extension

copyWithWrapped({Wrapped<LongreadMaterialDiscriminator>? discriminator, Wrapped<PublicationState>? state, Wrapped<LongreadMaterialViewType>? viewType, Wrapped<LongreadMaterialType>? type, Wrapped<int>? id, Wrapped<int>? order, Wrapped<FileMediaType>? mediaType, Wrapped<String>? filename, Wrapped<String?>? version, Wrapped<int>? length, Wrapped<String?>? publishDate, Wrapped<String?>? publishedAt, Wrapped<LongreadMaterialContent>? content}) LongreadVideoMaterialItem

Available on LongreadVideoMaterialItem, provided by the $LongreadVideoMaterialItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LongreadVideoMaterialItem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LongreadVideoMaterialItem instance)