LongreadVideoPlatformMaterialItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

LongreadVideoPlatformMaterialItem({required LongreadMaterialDiscriminator discriminator, required PublicationState state, required LongreadMaterialViewType viewType, required LongreadMaterialType type, required int id, required int order, required String name, required String description, required String videoId, required XRePropertyIncompleteOnlyEmptyArrayObserved timecodes, required String? publishDate, required VideoPlatformState videoState, required String url})
const
LongreadVideoPlatformMaterialItem.fromJson(Map<String, dynamic> json)
factory

Properties

description String
final
discriminator LongreadMaterialDiscriminator
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
name String
final
order int
final
publishDate String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state PublicationState
final
timecodes XRePropertyIncompleteOnlyEmptyArrayObserved
final
type LongreadMaterialType
final
url String
final
videoId String
final
videoState VideoPlatformState
final
viewType LongreadMaterialViewType
final

Methods

copyWith({LongreadMaterialDiscriminator? discriminator, PublicationState? state, LongreadMaterialViewType? viewType, LongreadMaterialType? type, int? id, int? order, String? name, String? description, String? videoId, XRePropertyIncompleteOnlyEmptyArrayObserved? timecodes, String? publishDate, VideoPlatformState? videoState, String? url}) LongreadVideoPlatformMaterialItem

Available on LongreadVideoPlatformMaterialItem, provided by the $LongreadVideoPlatformMaterialItemExtension extension

copyWithWrapped({Wrapped<LongreadMaterialDiscriminator>? discriminator, Wrapped<PublicationState>? state, Wrapped<LongreadMaterialViewType>? viewType, Wrapped<LongreadMaterialType>? type, Wrapped<int>? id, Wrapped<int>? order, Wrapped<String>? name, Wrapped<String>? description, Wrapped<String>? videoId, Wrapped<XRePropertyIncompleteOnlyEmptyArrayObserved>? timecodes, Wrapped<String?>? publishDate, Wrapped<VideoPlatformState>? videoState, Wrapped<String>? url}) LongreadVideoPlatformMaterialItem

Available on LongreadVideoPlatformMaterialItem, provided by the $LongreadVideoPlatformMaterialItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const LongreadVideoPlatformMaterialItem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(LongreadVideoPlatformMaterialItem instance)