Paging class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Paging({required int limit, required int offset, required int totalCount})
const
Paging.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
final
offset int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
final

Methods

copyWith({int? limit, int? offset, int? totalCount}) Paging

Available on Paging, provided by the $PagingExtension extension

copyWithWrapped({Wrapped<int>? limit, Wrapped<int>? offset, Wrapped<int>? totalCount}) Paging

Available on Paging, provided by the $PagingExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const Paging Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Paging instance)