QuestionItemCorrectAnswerInputNumberCorrectAnswer class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

QuestionItemCorrectAnswerInputNumberCorrectAnswer({required QuestionItemCorrectAnswerInputNumberCorrectAnswerType type, required List<double> variants, required bool showPrecisionHint, String? autoEvaluationPrecision, int? precision})
const
QuestionItemCorrectAnswerInputNumberCorrectAnswer.fromJson(Map<String, dynamic> json)
factory

Properties

autoEvaluationPrecision String?
final
hashCode int
The hash code for this object.
no setteroverride
precision int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPrecisionHint bool
final
type QuestionItemCorrectAnswerInputNumberCorrectAnswerType
final
variants List<double>
final

Methods

copyWith({QuestionItemCorrectAnswerInputNumberCorrectAnswerType? type, List<double>? variants, bool? showPrecisionHint, String? autoEvaluationPrecision, int? precision}) QuestionItemCorrectAnswerInputNumberCorrectAnswer

Available on QuestionItemCorrectAnswerInputNumberCorrectAnswer, provided by the $QuestionItemCorrectAnswerInputNumberCorrectAnswerExtension extension

copyWithWrapped({Wrapped<QuestionItemCorrectAnswerInputNumberCorrectAnswerType>? type, Wrapped<List<double>>? variants, Wrapped<bool>? showPrecisionHint, Wrapped<String?>? autoEvaluationPrecision, Wrapped<int?>? precision}) QuestionItemCorrectAnswerInputNumberCorrectAnswer

Available on QuestionItemCorrectAnswerInputNumberCorrectAnswer, provided by the $QuestionItemCorrectAnswerInputNumberCorrectAnswerExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override