TaskByIdResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

TaskByIdResponse({required int id, required TaskType type, required TaskState state, required num? score, TaskScoreSkillLevel? scoreSkillLevel, required bool isSkillLevelEnabled, required bool isLateDaysEnabled, required num? extraScore, required String createdAt, required String? startedAt, required String? submitAt, required String? rejectAt, required String? evaluateAt, required String deadline, required int? lateDays, required TaskExercise exercise, required TaskCourse course, required TaskCourseTheme theme, required TaskLongread longread, required CurrentStudentResponse student, required TaskReviewer? reviewer, required TaskSolution? solution, required List<TaskScoresItem>? scores, required QuizSessionId? quizSessionId, required TaskEvaluatedAttemptId? evaluatedAttemptId, required TaskCurrentAttemptId? currentAttemptId, required TaskLastAttemptId? lastAttemptId})
const
TaskByIdResponse.fromJson(Map<String, dynamic> json)
factory

Properties

course TaskCourse
final
createdAt String
final
currentAttemptId TaskCurrentAttemptId?
final
deadline String
final
evaluateAt String?
final
evaluatedAttemptId TaskEvaluatedAttemptId?
final
exercise TaskExercise
final
extraScore num?
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
isLateDaysEnabled bool
final
isSkillLevelEnabled bool
final
lastAttemptId TaskLastAttemptId?
final
lateDays int?
final
longread TaskLongread
final
quizSessionId QuizSessionId?
final
rejectAt String?
final
reviewer TaskReviewer?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score num?
final
scores List<TaskScoresItem>?
final
scoreSkillLevel TaskScoreSkillLevel?
final
solution TaskSolution?
final
startedAt String?
final
state TaskState
final
student CurrentStudentResponse
final
submitAt String?
final
theme TaskCourseTheme
final
type TaskType
final

Methods

copyWith({int? id, TaskType? type, TaskState? state, num? score, TaskScoreSkillLevel? scoreSkillLevel, bool? isSkillLevelEnabled, bool? isLateDaysEnabled, num? extraScore, String? createdAt, String? startedAt, String? submitAt, String? rejectAt, String? evaluateAt, String? deadline, int? lateDays, TaskExercise? exercise, TaskCourse? course, TaskCourseTheme? theme, TaskLongread? longread, CurrentStudentResponse? student, TaskReviewer? reviewer, TaskSolution? solution, List<TaskScoresItem>? scores, QuizSessionId? quizSessionId, TaskEvaluatedAttemptId? evaluatedAttemptId, TaskCurrentAttemptId? currentAttemptId, TaskLastAttemptId? lastAttemptId}) TaskByIdResponse

Available on TaskByIdResponse, provided by the $TaskByIdResponseExtension extension

copyWithWrapped({Wrapped<int>? id, Wrapped<TaskType>? type, Wrapped<TaskState>? state, Wrapped<num?>? score, Wrapped<TaskScoreSkillLevel?>? scoreSkillLevel, Wrapped<bool>? isSkillLevelEnabled, Wrapped<bool>? isLateDaysEnabled, Wrapped<num?>? extraScore, Wrapped<String>? createdAt, Wrapped<String?>? startedAt, Wrapped<String?>? submitAt, Wrapped<String?>? rejectAt, Wrapped<String?>? evaluateAt, Wrapped<String>? deadline, Wrapped<int?>? lateDays, Wrapped<TaskExercise>? exercise, Wrapped<TaskCourse>? course, Wrapped<TaskCourseTheme>? theme, Wrapped<TaskLongread>? longread, Wrapped<CurrentStudentResponse>? student, Wrapped<TaskReviewer?>? reviewer, Wrapped<TaskSolution?>? solution, Wrapped<List<TaskScoresItem>?>? scores, Wrapped<QuizSessionId?>? quizSessionId, Wrapped<TaskEvaluatedAttemptId?>? evaluatedAttemptId, Wrapped<TaskCurrentAttemptId?>? currentAttemptId, Wrapped<TaskLastAttemptId?>? lastAttemptId}) TaskByIdResponse

Available on TaskByIdResponse, provided by the $TaskByIdResponseExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const TaskByIdResponse Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(TaskByIdResponse instance)