TaskCourseTheme class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

TaskCourseTheme({required int id, required String name})
const
TaskCourseTheme.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? name}) TaskCourseTheme

Available on TaskCourseTheme, provided by the $TaskCourseThemeExtension extension

copyWithWrapped({Wrapped<int>? id, Wrapped<String>? name}) TaskCourseTheme

Available on TaskCourseTheme, provided by the $TaskCourseThemeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const TaskCourseTheme Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(TaskCourseTheme instance)