TaskExerciseQuestionOrderOptionOrder class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

TaskExerciseQuestionOrderOptionOrder({required int optionId, required int order})
const
TaskExerciseQuestionOrderOptionOrder.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
optionId int
final
order int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? optionId, int? order}) TaskExerciseQuestionOrderOptionOrder

Available on TaskExerciseQuestionOrderOptionOrder, provided by the $TaskExerciseQuestionOrderOptionOrderExtension extension

copyWithWrapped({Wrapped<int>? optionId, Wrapped<int>? order}) TaskExerciseQuestionOrderOptionOrder

Available on TaskExerciseQuestionOrderOptionOrder, provided by the $TaskExerciseQuestionOrderOptionOrderExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const TaskExerciseQuestionOrderOptionOrder Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(TaskExerciseQuestionOrderOptionOrder instance)