TaskReviewer class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- TaskReviewer({required String id, required String name, required String identityEmail, required String email, required String identityIdentifier, required String timeAccount, required String lastName, required String firstName, String? middleName})
-
const
-
TaskReviewer.fromJson(Map<
String, dynamic> json) -
factory
Properties
- email → String
-
final
- firstName → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- identityEmail → String
-
final
- identityIdentifier → String
-
final
- lastName → String
-
final
- middleName → String?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeAccount → String
-
final
Methods
-
copyWith(
{String? id, String? name, String? identityEmail, String? email, String? identityIdentifier, String? timeAccount, String? lastName, String? firstName, String? middleName}) → TaskReviewer -
Available on TaskReviewer, provided by the $TaskReviewerExtension extension
-
copyWithWrapped(
{Wrapped< String> ? id, Wrapped<String> ? name, Wrapped<String> ? identityEmail, Wrapped<String> ? email, Wrapped<String> ? identityIdentifier, Wrapped<String> ? timeAccount, Wrapped<String> ? lastName, Wrapped<String> ? firstName, Wrapped<String?> ? middleName}) → TaskReviewer -
Available on TaskReviewer, provided by the $TaskReviewerExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const TaskReviewer Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(TaskReviewer instance)