TaskSolution class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

TaskSolution({required TaskType type, String? solutionUrl, List<TaskSolutionAnswersItem>? answers, List<TaskAttachment>? attachments})
const
TaskSolution.fromJson(Map<String, dynamic> json)
factory

Properties

answers List<TaskSolutionAnswersItem>?
final
attachments List<TaskAttachment>?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
solutionUrl String?
final
type TaskType
final

Methods

copyWith({TaskType? type, String? solutionUrl, List<TaskSolutionAnswersItem>? answers, List<TaskAttachment>? attachments}) TaskSolution

Available on TaskSolution, provided by the $TaskSolutionExtension extension

copyWithWrapped({Wrapped<TaskType>? type, Wrapped<String?>? solutionUrl, Wrapped<List<TaskSolutionAnswersItem>?>? answers, Wrapped<List<TaskAttachment>?>? attachments}) TaskSolution

Available on TaskSolution, provided by the $TaskSolutionExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const TaskSolution Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(TaskSolution instance)