TaskSolutionAnswersItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

TaskSolutionAnswersItem({required dynamic answer, required TaskSolutionAnswersQuestion question})
const
TaskSolutionAnswersItem.fromJson(Map<String, dynamic> json)
factory

Properties

answer → dynamic
final
hashCode int
The hash code for this object.
no setteroverride
question TaskSolutionAnswersQuestion
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({dynamic answer, TaskSolutionAnswersQuestion? question}) TaskSolutionAnswersItem

Available on TaskSolutionAnswersItem, provided by the $TaskSolutionAnswersItemExtension extension

copyWithWrapped({Wrapped? answer, Wrapped<TaskSolutionAnswersQuestion>? question}) TaskSolutionAnswersItem

Available on TaskSolutionAnswersItem, provided by the $TaskSolutionAnswersItemExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const TaskSolutionAnswersItem Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(TaskSolutionAnswersItem instance)