TaskSolutionAnswersQuestionInputNumberQuestionItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- TaskSolutionAnswersQuestionInputNumberQuestionItem({required int id, required TaskSolutionAnswersQuestionInputNumberQuestionItemType type, required TaskSolutionAnswersQuestionInputNumberAnswer? answer, required NullOnly? options})
-
const
-
TaskSolutionAnswersQuestionInputNumberQuestionItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- answer → TaskSolutionAnswersQuestionInputNumberAnswer?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
- options → NullOnly?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → TaskSolutionAnswersQuestionInputNumberQuestionItemType
-
final
Methods
-
copyWith(
{int? id, TaskSolutionAnswersQuestionInputNumberQuestionItemType? type, TaskSolutionAnswersQuestionInputNumberAnswer? answer, NullOnly? options}) → TaskSolutionAnswersQuestionInputNumberQuestionItem -
Available on TaskSolutionAnswersQuestionInputNumberQuestionItem, provided by the $TaskSolutionAnswersQuestionInputNumberQuestionItemExtension extension
-
copyWithWrapped(
{Wrapped< int> ? id, Wrapped<TaskSolutionAnswersQuestionInputNumberQuestionItemType> ? type, Wrapped<TaskSolutionAnswersQuestionInputNumberAnswer?> ? answer, Wrapped<NullOnly?> ? options}) → TaskSolutionAnswersQuestionInputNumberQuestionItem -
Available on TaskSolutionAnswersQuestionInputNumberQuestionItem, provided by the $TaskSolutionAnswersQuestionInputNumberQuestionItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const TaskSolutionAnswersQuestionInputNumberQuestionItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(TaskSolutionAnswersQuestionInputNumberQuestionItem instance)