TaskSolutionAnswersQuestionOptionsItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- TaskSolutionAnswersQuestionOptionsItem({required int id, required bool isCorrect, required String? recommendation})
-
const
-
TaskSolutionAnswersQuestionOptionsItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
- isCorrect → bool
-
final
- recommendation → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? id, bool? isCorrect, String? recommendation}) → TaskSolutionAnswersQuestionOptionsItem -
Available on TaskSolutionAnswersQuestionOptionsItem, provided by the $TaskSolutionAnswersQuestionOptionsItemExtension extension
-
copyWithWrapped(
{Wrapped< int> ? id, Wrapped<bool> ? isCorrect, Wrapped<String?> ? recommendation}) → TaskSolutionAnswersQuestionOptionsItem -
Available on TaskSolutionAnswersQuestionOptionsItem, provided by the $TaskSolutionAnswersQuestionOptionsItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const TaskSolutionAnswersQuestionOptionsItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(TaskSolutionAnswersQuestionOptionsItem instance)