TaskSolutionAnswersQuestionOptionsQuestionItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
TaskSolutionAnswersQuestionOptionsQuestionItem({required int id, required TaskSolutionAnswersQuestionOptionsQuestionItemType type, required NullOnly? answer, required List<
TaskSolutionAnswersQuestionOptionsItem> options}) -
const
-
TaskSolutionAnswersQuestionOptionsQuestionItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- answer → NullOnly?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
-
options
→ List<
TaskSolutionAnswersQuestionOptionsItem> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → TaskSolutionAnswersQuestionOptionsQuestionItemType
-
final
Methods
-
copyWith(
{int? id, TaskSolutionAnswersQuestionOptionsQuestionItemType? type, NullOnly? answer, List< TaskSolutionAnswersQuestionOptionsItem> ? options}) → TaskSolutionAnswersQuestionOptionsQuestionItem -
Available on TaskSolutionAnswersQuestionOptionsQuestionItem, provided by the $TaskSolutionAnswersQuestionOptionsQuestionItemExtension extension
-
copyWithWrapped(
{Wrapped< int> ? id, Wrapped<TaskSolutionAnswersQuestionOptionsQuestionItemType> ? type, Wrapped<NullOnly?> ? answer, Wrapped<List< ? options}) → TaskSolutionAnswersQuestionOptionsQuestionItemTaskSolutionAnswersQuestionOptionsItem> > -
Available on TaskSolutionAnswersQuestionOptionsQuestionItem, provided by the $TaskSolutionAnswersQuestionOptionsQuestionItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const TaskSolutionAnswersQuestionOptionsQuestionItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(TaskSolutionAnswersQuestionOptionsQuestionItem instance)