LmsApi class abstract

Annotations
  • @ChopperApi.new()

Constructors

LmsApi()

Properties

client ↔ ChopperClient
getter/setter pairinherited
definitionType Type
Used internally to retrieve the service from ChopperClient.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

courseOverviewById({required int? courseId}) Future<Response<CourseOverviewByIdResponse>>
Get course overview by its ID. @param courseId Numeric identifier of the course specified in URL path.
courseSummaryById({required int? courseId}) Future<Response<CourseSummaryByIdResponse>>
Get course summary by its ID. @param courseId Numeric identifier of the course specified in URL path.
courseThemeSummaryById({required int? themeId}) Future<Response<CourseThemeSummaryByIdResponse>>
Get course theme summary by its ID. @param themeId Numeric identifier of the course theme specified in URL path.
currentStudent() Future<Response<CurrentStudentResponse>>
Get current student.
Generate content download link. @param filename File object path in storage specified in URL query. @param version Material content revision identifier specified in URL query.
listStudentCourses({int? limit, int? offset, List<PublicationState>? state}) Future<Response<ListStudentCoursesResponse>>
List courses for the current student. @param limit Maximum number of items to return. @param offset Number of items to skip before collecting result items. @param state Include only courses whose state matches any of the specified values.
longreadMaterialsById({required int? longreadId, int? limit, int? offset}) Future<Response<LongreadMaterialsByIdResponse>>
Get longread materials by its ID. @param longreadId Numeric identifier of the longread item specified in URL path. @param limit Maximum number of items to return. @param offset Number of items to skip before collecting result items.
longreadSummaryById({required int? longreadId}) Future<Response<LongreadSummaryByIdResponse>>
Get longread summary by its ID. @param longreadId Numeric identifier of the longread item specified in URL path.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
taskById({required int? taskId}) Future<Response<TaskByIdResponse>>
Get task by its ID. @param taskId Numeric identifier of the task item specified in URL path.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({ChopperClient? client, Client? httpClient, Authenticator? authenticator, ErrorConverter? errorConverter, Converter? converter, Uri? baseUrl, List<Interceptor>? interceptors}) LmsApi