listStudentCourses method

Future<Response<ListStudentCoursesResponse>> listStudentCourses({
  1. int? limit,
  2. int? offset,
  3. List<PublicationState>? state,
})

List courses for the current student. @param limit Maximum number of items to return. @param offset Number of items to skip before collecting result items. @param state Include only courses whose state matches any of the specified values.

Implementation

Future<chopper.Response<ListStudentCoursesResponse>> listStudentCourses({
  int? limit,
  int? offset,
  List<enums.PublicationState>? state,
}) {
  generatedMapping.putIfAbsent(
    ListStudentCoursesResponse,
    () => ListStudentCoursesResponse.fromJsonFactory,
  );

  return _listStudentCourses(
    limit: limit,
    offset: offset,
    state: publicationStateListToJson(state),
  );
}