CourseCategory enum
Values
- swaggerGeneratedUnknown → const CourseCategory
-
const CourseCategory(null) - withoutcategory → const CourseCategory
-
const CourseCategory('withoutCategory') - general → const CourseCategory
-
const CourseCategory('general') - mathematics → const CourseCategory
-
const CourseCategory('mathematics') - business → const CourseCategory
-
const CourseCategory('business') - development → const CourseCategory
-
const CourseCategory('development') - stem → const CourseCategory
-
const CourseCategory('stem') - softskills → const CourseCategory
-
const CourseCategory('softSkills') - ml → const CourseCategory
-
const CourseCategory('ml') - design → const CourseCategory
-
const CourseCategory('design') - analytics → const CourseCategory
-
const CourseCategory('analytics') - career → const CourseCategory
-
const CourseCategory('career') - management → const CourseCategory
-
const CourseCategory('management')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CourseCategory> - A constant List of the values in this enum, in order of their declaration.