CurrentStudentResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- CurrentStudentResponse({required String id, required String lastName, required String firstName, String? middleName, required String universityEmail, required String timeAccount, int? studyStartYear, required StudyLevel studyLevel, required int lateDaysBalance})
-
const
-
CurrentStudentResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- firstName → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- lastName → String
-
final
- lateDaysBalance → int
-
final
- middleName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- studyLevel → StudyLevel
-
final
- studyStartYear → int?
-
final
- timeAccount → String
-
final
- universityEmail → String
-
final
Methods
-
copyWith(
{String? id, String? lastName, String? firstName, String? middleName, String? universityEmail, String? timeAccount, int? studyStartYear, StudyLevel? studyLevel, int? lateDaysBalance}) → CurrentStudentResponse -
Available on CurrentStudentResponse, provided by the $CurrentStudentResponseExtension extension
-
copyWithWrapped(
{Wrapped< String> ? id, Wrapped<String> ? lastName, Wrapped<String> ? firstName, Wrapped<String?> ? middleName, Wrapped<String> ? universityEmail, Wrapped<String> ? timeAccount, Wrapped<int?> ? studyStartYear, Wrapped<StudyLevel> ? studyLevel, Wrapped<int> ? lateDaysBalance}) → CurrentStudentResponse -
Available on CurrentStudentResponse, provided by the $CurrentStudentResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const CurrentStudentResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(CurrentStudentResponse instance)