ExerciseQuestionsSettings class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- ExerciseQuestionsSettings({String? questionsPerAttempt, required int attemptsLimit, required QuestionsSettingsEvalStrategy evaluationStrategy})
-
const
-
ExerciseQuestionsSettings.fromJson(Map<
String, dynamic> json) -
factory
Properties
- attemptsLimit → int
-
final
- evaluationStrategy → QuestionsSettingsEvalStrategy
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- questionsPerAttempt → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? questionsPerAttempt, int? attemptsLimit, QuestionsSettingsEvalStrategy? evaluationStrategy}) → ExerciseQuestionsSettings -
Available on ExerciseQuestionsSettings, provided by the $ExerciseQuestionsSettingsExtension extension
-
copyWithWrapped(
{Wrapped< String?> ? questionsPerAttempt, Wrapped<int> ? attemptsLimit, Wrapped<QuestionsSettingsEvalStrategy> ? evaluationStrategy}) → ExerciseQuestionsSettings -
Available on ExerciseQuestionsSettings, provided by the $ExerciseQuestionsSettingsExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const ExerciseQuestionsSettings Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(ExerciseQuestionsSettings instance)