LongreadExerciseCodingMaterialItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
LongreadExerciseCodingMaterialItem({required LongreadMaterialDiscriminator discriminator, required PublicationState state, required LongreadMaterialViewType viewType, required LongreadMaterialType type, required int id, required int order, required String name, required String? viewContent, required LongreadMaterialEstimation estimation, required List<
String> reviewers, required List<String> assignees, required List<LongreadMaterialAttachmentItem> attachments, required String? backloggedAt, required int taskId, required bool isTrackingStudents, required String? exerciseUrl, required LongreadMaterialCoding coding}) -
const
-
LongreadExerciseCodingMaterialItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
assignees
→ List<
String> -
final
-
attachments
→ List<
LongreadMaterialAttachmentItem> -
final
- backloggedAt → String?
-
final
- coding → LongreadMaterialCoding
-
final
- discriminator → LongreadMaterialDiscriminator
-
final
- estimation → LongreadMaterialEstimation
-
final
- exerciseUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
- isTrackingStudents → bool
-
final
- name → String
-
final
- order → int
-
final
-
reviewers
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → PublicationState
-
final
- taskId → int
-
final
- type → LongreadMaterialType
-
final
- viewContent → String?
-
final
- viewType → LongreadMaterialViewType
-
final
Methods
-
copyWith(
{LongreadMaterialDiscriminator? discriminator, PublicationState? state, LongreadMaterialViewType? viewType, LongreadMaterialType? type, int? id, int? order, String? name, String? viewContent, LongreadMaterialEstimation? estimation, List< String> ? reviewers, List<String> ? assignees, List<LongreadMaterialAttachmentItem> ? attachments, String? backloggedAt, int? taskId, bool? isTrackingStudents, String? exerciseUrl, LongreadMaterialCoding? coding}) → LongreadExerciseCodingMaterialItem -
Available on LongreadExerciseCodingMaterialItem, provided by the $LongreadExerciseCodingMaterialItemExtension extension
-
copyWithWrapped(
{Wrapped< LongreadMaterialDiscriminator> ? discriminator, Wrapped<PublicationState> ? state, Wrapped<LongreadMaterialViewType> ? viewType, Wrapped<LongreadMaterialType> ? type, Wrapped<int> ? id, Wrapped<int> ? order, Wrapped<String> ? name, Wrapped<String?> ? viewContent, Wrapped<LongreadMaterialEstimation> ? estimation, Wrapped<List< ? reviewers, Wrapped<String> >List< ? assignees, Wrapped<String> >List< ? attachments, Wrapped<LongreadMaterialAttachmentItem> >String?> ? backloggedAt, Wrapped<int> ? taskId, Wrapped<bool> ? isTrackingStudents, Wrapped<String?> ? exerciseUrl, Wrapped<LongreadMaterialCoding> ? coding}) → LongreadExerciseCodingMaterialItem -
Available on LongreadExerciseCodingMaterialItem, provided by the $LongreadExerciseCodingMaterialItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const LongreadExerciseCodingMaterialItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(LongreadExerciseCodingMaterialItem instance)