LongreadExerciseInputQuestionItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
LongreadExerciseInputQuestionItem({required LongreadExerciseInputQuestionItemType type, required int id, required int order, required String content, required num score, required List<
LongreadMaterialAttachmentItem> attachments, required QuestionItemCorrectAnswer? correctAnswer, required bool autoEvaluation, required String? recommendation, required QuestionItemEvaluationBlock input}) -
const
-
LongreadExerciseInputQuestionItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
attachments
→ List<
LongreadMaterialAttachmentItem> -
final
- autoEvaluation → bool
-
final
- content → String
-
final
- correctAnswer → QuestionItemCorrectAnswer?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
- input → QuestionItemEvaluationBlock
-
final
- order → int
-
final
- recommendation → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → num
-
final
- type → LongreadExerciseInputQuestionItemType
-
final
Methods
-
copyWith(
{LongreadExerciseInputQuestionItemType? type, int? id, int? order, String? content, num? score, List< LongreadMaterialAttachmentItem> ? attachments, QuestionItemCorrectAnswer? correctAnswer, bool? autoEvaluation, String? recommendation, QuestionItemEvaluationBlock? input}) → LongreadExerciseInputQuestionItem -
Available on LongreadExerciseInputQuestionItem, provided by the $LongreadExerciseInputQuestionItemExtension extension
-
copyWithWrapped(
{Wrapped< LongreadExerciseInputQuestionItemType> ? type, Wrapped<int> ? id, Wrapped<int> ? order, Wrapped<String> ? content, Wrapped<num> ? score, Wrapped<List< ? attachments, Wrapped<LongreadMaterialAttachmentItem> >QuestionItemCorrectAnswer?> ? correctAnswer, Wrapped<bool> ? autoEvaluation, Wrapped<String?> ? recommendation, Wrapped<QuestionItemEvaluationBlock> ? input}) → LongreadExerciseInputQuestionItem -
Available on LongreadExerciseInputQuestionItem, provided by the $LongreadExerciseInputQuestionItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const LongreadExerciseInputQuestionItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(LongreadExerciseInputQuestionItem instance)