LongreadMarkdownMaterialItem class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- LongreadMarkdownMaterialItem({required LongreadMaterialDiscriminator discriminator, required PublicationState state, required LongreadMaterialViewType viewType, required LongreadMaterialType type, required int id, required int order, required String viewContent, required String? publishDate, required String? publishedAt})
-
const
-
LongreadMarkdownMaterialItem.fromJson(Map<
String, dynamic> json) -
factory
Properties
- discriminator → LongreadMaterialDiscriminator
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
- order → int
-
final
- publishDate → String?
-
final
- publishedAt → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → PublicationState
-
final
- type → LongreadMaterialType
-
final
- viewContent → String
-
final
- viewType → LongreadMaterialViewType
-
final
Methods
-
copyWith(
{LongreadMaterialDiscriminator? discriminator, PublicationState? state, LongreadMaterialViewType? viewType, LongreadMaterialType? type, int? id, int? order, String? viewContent, String? publishDate, String? publishedAt}) → LongreadMarkdownMaterialItem -
Available on LongreadMarkdownMaterialItem, provided by the $LongreadMarkdownMaterialItemExtension extension
-
copyWithWrapped(
{Wrapped< LongreadMaterialDiscriminator> ? discriminator, Wrapped<PublicationState> ? state, Wrapped<LongreadMaterialViewType> ? viewType, Wrapped<LongreadMaterialType> ? type, Wrapped<int> ? id, Wrapped<int> ? order, Wrapped<String> ? viewContent, Wrapped<String?> ? publishDate, Wrapped<String?> ? publishedAt}) → LongreadMarkdownMaterialItem -
Available on LongreadMarkdownMaterialItem, provided by the $LongreadMarkdownMaterialItemExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const LongreadMarkdownMaterialItem Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(LongreadMarkdownMaterialItem instance)