LongreadMaterialActivity class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- LongreadMaterialActivity({required int id, required String name, required num weight, required double maxExercisesCount, double? averageScoreThreshold, required bool isLateDaysEnabled})
-
const
-
LongreadMaterialActivity.fromJson(Map<
String, dynamic> json) -
factory
Properties
- averageScoreThreshold → double?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
- isLateDaysEnabled → bool
-
final
- maxExercisesCount → double
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- weight → num
-
final
Methods
-
copyWith(
{int? id, String? name, num? weight, double? maxExercisesCount, double? averageScoreThreshold, bool? isLateDaysEnabled}) → LongreadMaterialActivity -
Available on LongreadMaterialActivity, provided by the $LongreadMaterialActivityExtension extension
-
copyWithWrapped(
{Wrapped< int> ? id, Wrapped<String> ? name, Wrapped<num> ? weight, Wrapped<double> ? maxExercisesCount, Wrapped<double?> ? averageScoreThreshold, Wrapped<bool> ? isLateDaysEnabled}) → LongreadMaterialActivity -
Available on LongreadMaterialActivity, provided by the $LongreadMaterialActivityExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const LongreadMaterialActivity Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(LongreadMaterialActivity instance)