LongreadSummaryByIdResponse class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- LongreadSummaryByIdResponse({required int id, required LongreadType type, required String name, required int order, required PublicationState state, required String? publishDate, required String? publishedAt})
-
const
-
LongreadSummaryByIdResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
- name → String
-
final
- order → int
-
final
- publishDate → String?
-
final
- publishedAt → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → PublicationState
-
final
- type → LongreadType
-
final
Methods
-
copyWith(
{int? id, LongreadType? type, String? name, int? order, PublicationState? state, String? publishDate, String? publishedAt}) → LongreadSummaryByIdResponse -
Available on LongreadSummaryByIdResponse, provided by the $LongreadSummaryByIdResponseExtension extension
-
copyWithWrapped(
{Wrapped< int> ? id, Wrapped<LongreadType> ? type, Wrapped<String> ? name, Wrapped<int> ? order, Wrapped<PublicationState> ? state, Wrapped<String?> ? publishDate, Wrapped<String?> ? publishedAt}) → LongreadSummaryByIdResponse -
Available on LongreadSummaryByIdResponse, provided by the $LongreadSummaryByIdResponseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const LongreadSummaryByIdResponse Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(LongreadSummaryByIdResponse instance)