QuestionItemEvaluationBlock class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
- QuestionItemEvaluationBlock({required QuestionItemCorrectAnswer? correctAnswer, required bool autoEvaluation, required String recommendation})
-
const
-
QuestionItemEvaluationBlock.fromJson(Map<
String, dynamic> json) -
factory
Properties
- autoEvaluation → bool
-
final
- correctAnswer → QuestionItemCorrectAnswer?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- recommendation → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{QuestionItemCorrectAnswer? correctAnswer, bool? autoEvaluation, String? recommendation}) → QuestionItemEvaluationBlock -
Available on QuestionItemEvaluationBlock, provided by the $QuestionItemEvaluationBlockExtension extension
-
copyWithWrapped(
{Wrapped< QuestionItemCorrectAnswer?> ? correctAnswer, Wrapped<bool> ? autoEvaluation, Wrapped<String> ? recommendation}) → QuestionItemEvaluationBlock -
Available on QuestionItemEvaluationBlock, provided by the $QuestionItemEvaluationBlockExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const QuestionItemEvaluationBlock Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(QuestionItemEvaluationBlock instance)