TaskExercise class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
TaskExercise({required int id, required String name, required TaskType type, required num maxScore, required String startDate, required String deadline, String? timer, required TaskExerciseActivity activity, required List<
TaskExerciseQuestionOrder> ? questionOrders, bool? areQuestionsShuffled, int? quizId, String? mode, required String? viewContent, required String? exerciseUrl, List<TaskAttachment> ? attachments, ExerciseQuestionsSettings? settings}) -
const
-
TaskExercise.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activity → TaskExerciseActivity
-
final
- areQuestionsShuffled → bool?
-
final
-
attachments
→ List<
TaskAttachment> ? -
final
- deadline → String
-
final
- exerciseUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
final
- maxScore → num
-
final
- mode → String?
-
final
- name → String
-
final
-
questionOrders
→ List<
TaskExerciseQuestionOrder> ? -
final
- quizId → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → ExerciseQuestionsSettings?
-
final
- startDate → String
-
final
- timer → String?
-
final
- type → TaskType
-
final
- viewContent → String?
-
final
Methods
-
copyWith(
{int? id, String? name, TaskType? type, num? maxScore, String? startDate, String? deadline, String? timer, TaskExerciseActivity? activity, List< TaskExerciseQuestionOrder> ? questionOrders, bool? areQuestionsShuffled, int? quizId, String? mode, String? viewContent, String? exerciseUrl, List<TaskAttachment> ? attachments, ExerciseQuestionsSettings? settings}) → TaskExercise -
Available on TaskExercise, provided by the $TaskExerciseExtension extension
-
copyWithWrapped(
{Wrapped< int> ? id, Wrapped<String> ? name, Wrapped<TaskType> ? type, Wrapped<num> ? maxScore, Wrapped<String> ? startDate, Wrapped<String> ? deadline, Wrapped<String?> ? timer, Wrapped<TaskExerciseActivity> ? activity, Wrapped<List< ? questionOrders, Wrapped<TaskExerciseQuestionOrder> ?>bool?> ? areQuestionsShuffled, Wrapped<int?> ? quizId, Wrapped<String?> ? mode, Wrapped<String?> ? viewContent, Wrapped<String?> ? exerciseUrl, Wrapped<List< ? attachments, Wrapped<TaskAttachment> ?>ExerciseQuestionsSettings?> ? settings}) → TaskExercise -
Available on TaskExercise, provided by the $TaskExerciseExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const TaskExercise Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(TaskExercise instance)