TaskExerciseQuestionOrder class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
TaskExerciseQuestionOrder({required int questionId, required int order, required List<
TaskExerciseQuestionOrderOptionOrder> optionOrders}) -
const
-
TaskExerciseQuestionOrder.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
optionOrders
→ List<
TaskExerciseQuestionOrderOptionOrder> -
final
- order → int
-
final
- questionId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? questionId, int? order, List< TaskExerciseQuestionOrderOptionOrder> ? optionOrders}) → TaskExerciseQuestionOrder -
Available on TaskExerciseQuestionOrder, provided by the $TaskExerciseQuestionOrderExtension extension
-
copyWithWrapped(
{Wrapped< int> ? questionId, Wrapped<int> ? order, Wrapped<List< ? optionOrders}) → TaskExerciseQuestionOrderTaskExerciseQuestionOrderOptionOrder> > -
Available on TaskExerciseQuestionOrder, provided by the $TaskExerciseQuestionOrderExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const TaskExerciseQuestionOrder Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(TaskExerciseQuestionOrder instance)