TaskSolutionAnswersQuestionInputAnswer class
- Available extensions
- Annotations
-
- @JsonSerializable.new(explicitToJson: true)
Constructors
-
TaskSolutionAnswersQuestionInputAnswer({required List<
String> values, required TaskSolutionAnswersQuestionInputAnswerValue value, required String recommendation}) -
const
-
TaskSolutionAnswersQuestionInputAnswer.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- recommendation → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → TaskSolutionAnswersQuestionInputAnswerValue
-
final
-
values
→ List<
String> -
final
Methods
-
copyWith(
{List< String> ? values, TaskSolutionAnswersQuestionInputAnswerValue? value, String? recommendation}) → TaskSolutionAnswersQuestionInputAnswer -
Available on TaskSolutionAnswersQuestionInputAnswer, provided by the $TaskSolutionAnswersQuestionInputAnswerExtension extension
-
copyWithWrapped(
{Wrapped< List< ? values, Wrapped<String> >TaskSolutionAnswersQuestionInputAnswerValue> ? value, Wrapped<String> ? recommendation}) → TaskSolutionAnswersQuestionInputAnswer -
Available on TaskSolutionAnswersQuestionInputAnswer, provided by the $TaskSolutionAnswersQuestionInputAnswerExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
-
fromJsonFactory
→ const TaskSolutionAnswersQuestionInputAnswer Function(Map<
String, dynamic> json) -
toJsonFactory
→ const Map<
String, dynamic> Function(TaskSolutionAnswersQuestionInputAnswer instance)